pub unsafe trait SliceOrSized { }Expand description
Marks types that are slices or Sized.
In other words, this ensures Self is not a trait object (or extern type, which are unstable).
pub unsafe trait SliceOrSized { }Marks types that are slices or Sized.
In other words, this ensures Self is not a trait object (or extern type, which are unstable).