Enum RemoveError

pub enum RemoveError {
    IndexOutOfBounds {
        index: NonZeroUsize,
        len: NonZeroUsize,
    },
    WouldBecomeEmpty,
    Both {
        index: NonZeroUsize,
        len: NonZeroUsize,
    },
}
Available on crate feature alloc only.
Error returned when removing an element fails.

Variants



IndexOutOfBounds

The index is greater or equal to the number of elements.

Fields

index: NonZeroUsize

The index used for attempted access.

len: NonZeroUsize

The total number of elements stored.



WouldBecomeEmpty

Removing the element would leave an empty vec.



Both

Both the index is out of bounds and the vec would become empty after removing the element.

Fields

index: NonZeroUsize

The index used for attempted access.

len: NonZeroUsize

The total number of elements stored.

Implementations

Source

impl RemoveError

pub fn is_oob(&self) -> bool

Returns true if there was out-of-bounds access.

Note that this also returns true for the Both variant.

pub fn is_would_become_empty(&self) -> bool

Returns true if the resulting vec would become empty after removing the element.

Note that this also returns true for the Both variant.