pub enum RemoveError {
IndexOutOfBounds {
index: NonZeroUsize,
len: NonZeroUsize,
},
WouldBecomeEmpty,
Both {
index: NonZeroUsize,
len: NonZeroUsize,
},
}Available on crate feature
alloc only.Expand description
Error returned when removing an element fails.
Variants
IndexOutOfBounds
The index is greater or equal to the number of elements.
Fields

index: NonZeroUsizeThe index used for attempted access.

len: NonZeroUsizeThe total number of elements stored.
WouldBecomeEmpty
Removing the element would leave an empty vec.
Both
Both the index is out of bounds and the vec would become empty after removing the element.
Fields

index: NonZeroUsizeThe index used for attempted access.

len: NonZeroUsizeThe total number of elements stored.
Implementations
Sourceimpl RemoveError
impl RemoveError
Sourcepub fn is_oob(&self) -> bool
pub fn is_oob(&self) -> bool
Returns true if there was out-of-bounds access.
Note that this also returns true for the Both variant.
Sourcepub fn is_would_become_empty(&self) -> bool
pub fn is_would_become_empty(&self) -> bool
Returns true if the resulting vec would become empty after removing the element.
Note that this also returns true for the Both variant.